package cn.com.infosec.x509;

import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.util.Arrays;
import cn.com.infosec.util.Selector;
import cn.com.infosec.x509.extension.X509ExtensionUtil;
import java.io.IOException;
import java.math.BigInteger;
import java.security.cert.CRL;
import java.security.cert.X509CRL;
import java.security.cert.X509CRLSelector;

public class X509CRLStoreSelector extends X509CRLSelector implements Selector {
   private boolean deltaCRLIndicator = false;
   private boolean completeCRLEnabled = false;
   private BigInteger maxBaseCRLNumber = null;
   private byte[] issuingDistributionPoint = null;
   private boolean issuingDistributionPointEnabled = false;
   private X509AttributeCertificate attrCertChecking;

   public static X509CRLStoreSelector getInstance(X509CRLSelector selector) {
      if (selector != null) {
         X509CRLStoreSelector var1;
         X509CRLStoreSelector var10000 = var1 = new X509CRLStoreSelector;
         X509CRLStoreSelector var10007 = var1;
         X509CRLSelector var10008 = selector;
         var1.<init>();
         var1.setCertificateChecking(selector.getCertificateChecking());
         var1.setDateAndTime(selector.getDateAndTime());

         try {
            var10007.setIssuerNames(var10008.getIssuerNames());
         } catch (IOException var2) {
            throw new IllegalArgumentException(var2.getMessage());
         }

         var1.setIssuers(selector.getIssuers());
         var1.setMaxCRLNumber(selector.getMaxCRL());
         var10000.setMinCRLNumber(selector.getMinCRL());
         return var10000;
      } else {
         throw new IllegalArgumentException("cannot create from null selector");
      }
   }

   public boolean isIssuingDistributionPointEnabled() {
      return this.issuingDistributionPointEnabled;
   }

   public void setIssuingDistributionPointEnabled(boolean issuingDistributionPointEnabled) {
      this.issuingDistributionPointEnabled = issuingDistributionPointEnabled;
   }

   public void setAttrCertificateChecking(X509AttributeCertificate attrCert) {
      this.attrCertChecking = attrCert;
   }

   public X509AttributeCertificate getAttrCertificateChecking() {
      return this.attrCertChecking;
   }

   public boolean match(Object obj) {
      if (!(obj instanceof X509CRL)) {
         return false;
      } else {
         X509CRL obj1;
         X509CRL var10000 = obj1 = (X509CRL)obj;
         DERInteger var2 = null;

         boolean var10001;
         byte[] var8;
         try {
            var8 = var10000.getExtensionValue(X509Extensions.DeltaCRLIndicator.getId());
         } catch (Exception var5) {
            var10001 = false;
            return false;
         }

         byte[] var3 = var8;
         if (var8 != null) {
            DERInteger var9;
            try {
               var9 = DERInteger.getInstance(X509ExtensionUtil.fromExtensionValue(var3));
            } catch (Exception var4) {
               var10001 = false;
               return false;
            }

            var2 = var9;
         }

         if (this.isDeltaCRLIndicatorEnabled() && var2 == null) {
            return false;
         } else if (this.isCompleteCRLEnabled() && var2 != null) {
            return false;
         } else if (var2 != null && this.maxBaseCRLNumber != null && var2.getPositiveValue().compareTo(this.maxBaseCRLNumber) == 1) {
            return false;
         } else {
            if (this.issuingDistributionPointEnabled) {
               byte[] var7 = obj1.getExtensionValue(X509Extensions.IssuingDistributionPoint.getId());
               if ((var3 = this.issuingDistributionPoint) == null) {
                  if (var7 != null) {
                     return false;
                  }
               } else if (!Arrays.areEqual(var7, var3)) {
                  return false;
               }
            }

            return super.match(obj1);
         }
      }
   }

   public boolean match(CRL crl) {
      return this.match((Object)crl);
   }

   public boolean isDeltaCRLIndicatorEnabled() {
      return this.deltaCRLIndicator;
   }

   public void setDeltaCRLIndicatorEnabled(boolean deltaCRLIndicator) {
      this.deltaCRLIndicator = deltaCRLIndicator;
   }

   public Object clone() {
      X509CRLStoreSelector var1;
      X509CRLStoreSelector var10000 = var1 = getInstance(this);
      var1.deltaCRLIndicator = this.deltaCRLIndicator;
      var1.completeCRLEnabled = this.completeCRLEnabled;
      var1.maxBaseCRLNumber = this.maxBaseCRLNumber;
      var1.attrCertChecking = this.attrCertChecking;
      var1.issuingDistributionPointEnabled = this.issuingDistributionPointEnabled;
      var10000.issuingDistributionPoint = Arrays.clone(this.issuingDistributionPoint);
      return var10000;
   }

   public boolean isCompleteCRLEnabled() {
      return this.completeCRLEnabled;
   }

   public void setCompleteCRLEnabled(boolean completeCRLEnabled) {
      this.completeCRLEnabled = completeCRLEnabled;
   }

   public BigInteger getMaxBaseCRLNumber() {
      return this.maxBaseCRLNumber;
   }

   public void setMaxBaseCRLNumber(BigInteger maxBaseCRLNumber) {
      this.maxBaseCRLNumber = maxBaseCRLNumber;
   }

   public byte[] getIssuingDistributionPoint() {
      return Arrays.clone(this.issuingDistributionPoint);
   }

   public void setIssuingDistributionPoint(byte[] issuingDistributionPoint) {
      this.issuingDistributionPoint = Arrays.clone(issuingDistributionPoint);
   }
}
